**2.0.0 - 02/13/19**

 - Full rewrite of risk distributions.
 - Separation of input data handling from parameter calculation.
 - Improved interactive usability.

**1.0.1 - 11/07/18**

 - Clean up separated distributions.
 - Allow for only mean and standard deviation or pre-calculated parameters.

**1.0.0 - 10/29/18**

 - Initial Release

